@@ -1,7 +1,7 @@
 
-__version__ = "0.6.0"
+__version__ = "0.6.1"
 
 
 from .connector import MysqlPool, MysqlConnection, SqlGenerator, MysqlSqler
-from query_util import MysqlQueryUtil
+from .query_util import MysqlQueryUtil
 __all__ = ["SqlGenerator", "MysqlConnection", "MysqlPool", "MysqlSqler", "MysqlQueryUtil"]
